if __name__ == '__main__':
    import astmain_py777.astmain as __  # 本地包

    spider = __.spider.SPIDER
    wind_find_name = __.spider.SPIDER.wind_find_name
    obj1 = wind_find_name("Google")
    print("obj1                 :", obj1)

    import ctypes

    # ctypes.windll.user32.SendMessageW(obj1["hwnd"], 0x0112, 0xF020, 0)

    window_style = ctypes.windll.user32.GetWindowLongW(obj1["hwnd"], -16)  # -16 代表 GWL_STYLE
    window_style &= ~0x10000000  # 清除 WS_VISIBLE 标志位
    ctypes.windll.user32.SetWindowLongW(obj1["hwnd"], -16, window_style)



import asyncio
import datetime
from multiprocessing import freeze_support

from pyppeteer import launch

__ = None

import astmain_py777.astmain as __  # 本地包


def my_set_win_taskbar_hide():
    exe1 = __.win_find_name("oog")
    if exe1:
        print("有找到程序 exe1                 :", exe1)
        hwnd = exe1["hwnd"]
        result = __.win_hide_taskbar(hwnd)
        print("result                 :", result)
        result if print("成功:隐藏了程序_任务栏") else print("失败:未隐藏程序_任务栏")
    else:
        print("没找到程序 exe1                 :", exe1)


if __name__ == '__main__':
    async def aaa():
        opt = dict(
            title="title333小许" + datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S"),
            content="content333",
            files=[r"C:\Users\Administrator\Desktop\111.png", r"C:\Users\Administrator\Desktop\222.png"],
            cookies_str="""[
    {
        "name": "abRequestId",
        "value": "8c000796-7b13-5489-b50a-323172dea808",
        "domain": ".xiaohongshu.com",
        "hostOnly": false,
        "path": "/",
        "secure": false,
        "httpOnly": false,
        "session": false,
        "expirationDate": 1750573302.787641,
        "sameSite": "unspecified"
    },
    {
        "name": "a1",
        "value": "1903e9b9990f0a0g9zdck8w46x6qxkhtwbuxh7vhd50000162929",
        "domain": ".xiaohongshu.com",
        "hostOnly": false,
        "path": "/",
        "secure": false,
        "httpOnly": false,
        "session": false,
        "expirationDate": 1750573303,
        "sameSite": "unspecified"
    },
    {
        "name": "webId",
        "value": "6e5373c836a5fafd6ebec9da5931c12d",
        "domain": ".xiaohongshu.com",
        "hostOnly": false,
        "path": "/",
        "secure": false,
        "httpOnly": false,
        "session": false,
        "expirationDate": 1750573303,
        "sameSite": "unspecified"
    },
    {
        "name": "gid",
        "value": "yj8qdjD0qYEJyj8qdjDjjDWhj8i808kjufST7xfYE4KCKC28ACTx9x888yKJjJj8dKWfyiK8",
        "domain": ".xiaohongshu.com",
        "hostOnly": false,
        "path": "/",
        "secure": false,
        "httpOnly": false,
        "session": false,
        "expirationDate": 1754124806.455951,
        "sameSite": "unspecified"
    },
    {
        "name": "acw_tc",
        "value": "3e6c448464d52b812766be662eb810c66f346f0190814a4164de89721b4fa235",
        "domain": "www.xiaohongshu.com",
        "hostOnly": true,
        "path": "/",
        "secure": false,
        "httpOnly": true,
        "session": false,
        "expirationDate": 1719566551.747954,
        "sameSite": "unspecified"
    },
    {
        "name": "webBuild",
        "value": "4.23.1",
        "domain": ".xiaohongshu.com",
        "hostOnly": false,
        "path": "/",
        "secure": false,
        "httpOnly": false,
        "session": true,
        "sameSite": "unspecified"
    },
    {
        "name": "web_session",
        "value": "0400698e30a4ad561bd286314b344b5739cce4",
        "domain": ".xiaohongshu.com",
        "hostOnly": false,
        "path": "/",
        "secure": true,
        "httpOnly": true,
        "session": false,
        "expirationDate": 1751100783.717251,
        "sameSite": "unspecified"
    },
    {
        "name": "unread",
        "value": "{%22ub%22:%226676f2e3000000001d01b468%22%2C%22ue%22:%226679108c000000001f007ed8%22%2C%22uc%22:30}",
        "domain": ".xiaohongshu.com",
        "hostOnly": false,
        "path": "/",
        "secure": false,
        "httpOnly": false,
        "session": true,
        "sameSite": "unspecified"
    },
    {
        "name": "websectiga",
        "value": "7750c37de43b7be9de8ed9ff8ea0e576519e8cd2157322eb972ecb429a7735d4",
        "domain": ".xiaohongshu.com",
        "hostOnly": false,
        "path": "/",
        "secure": false,
        "httpOnly": false,
        "session": false,
        "expirationDate": 1719823990,
        "sameSite": "unspecified"
    },
    {
        "name": "sec_poison_id",
        "value": "37025440-4d43-4a20-a7cd-b4a0d2a3348e",
        "domain": ".xiaohongshu.com",
        "hostOnly": false,
        "path": "/",
        "secure": false,
        "httpOnly": false,
        "session": false,
        "expirationDate": 1719565395,
        "sameSite": "unspecified"
    },
    {
        "name": "galaxy_creator_session_id",
        "value": "qhvQEnEHXSJ8QXXyzWlcIwkieFxxviFTXcv3",
        "domain": ".xiaohongshu.com",
        "hostOnly": false,
        "path": "/",
        "secure": false,
        "httpOnly": false,
        "session": false,
        "expirationDate": 1720169604.780629,
        "sameSite": "unspecified"
    },
    {
        "name": "galaxy.creator.beaker.session.id",
        "value": "1719564804173011837940",
        "domain": ".xiaohongshu.com",
        "hostOnly": false,
        "path": "/",
        "secure": false,
        "httpOnly": false,
        "session": false,
        "expirationDate": 1720169604.780666,
        "sameSite": "unspecified"
    },
    {
        "name": "xsecappid",
        "value": "creator-creator",
        "domain": ".xiaohongshu.com",
        "hostOnly": false,
        "path": "/",
        "secure": false,
        "httpOnly": false,
        "session": false,
        "expirationDate": 1751100805,
        "sameSite": "unspecified"
    }
]""",
        )

        opt["cookies"] = __.to_json(opt["cookies_str"])
        spider = await __.spider.spider_pyppeteer(desc="全部显示位置", x=0, y=0)
        # spider = await __.spider.spider_pyppeteer(desc="全部隐藏位置",x=0, y=-900 + 2)
        # spider = await __.spider.spider_pyppeteer(desc="一点隐藏位置", x=0, y=-900 + 100)
        # await spider.web_set_cookies(desc="小红书设置cookies", cookies=opt["cookies"])
        await spider.web_set_cookies(desc="小红书设置cookies", cookies=opt["cookies"])
        await spider.web_goto(desc="小红书首页home", url="https://creator.xiaohongshu.com")
        await spider.web_goto(desc="小红书发布页面", url="https://creator.xiaohongshu.com/publish/publish")
        await spider.web_await_click(desc="上传按钮", css=".tab:nth-child(2)")
        await spider.web_await_input_files(desc="上传完图片", css=".upload-input", files=opt["files"])
        await spider.web_await_input_text(desc="输入标题", css=".titleInput .el-input__wrapper .el-input__inner", text=opt["title"])
        await spider.web_await_input_text(desc="输入描述", css=".topic-container", text=opt["content"])
        await spider.web_await_click(desc="权限设置_私密", css=".el-radio__label")
        await spider.web_await_click(desc="点击发布按钮", css=".publishBtn")
        # await __.tool_await(0.1)
        # await __.tool_await(9999)
        await spider.web_await_css_close_browser(desc="完美!!!发布成功", css=".btn-content")


    asyncio.get_event_loop().run_until_complete(aaa())



from subprocess import run as subprocess_run


def run(cmd_str='', echo_print=1):
    """
    执行cmd命令，不显示执行过程中弹出的黑框
    备注：subprocess.run()函数会将本来打印到cmd上的内容打印到python执行界面上，所以避免了出现cmd弹出框的问题
    :param cmd_str: 执行的cmd命令
    :return:
    """

    if echo_print == 1:
        print('\n执行cmd指令="{}"'.format(cmd_str))
    subprocess_run(cmd_str, shell=True)



class to_obj_dict:
    """ EXPLAIN :  日志追加记录函数
        EXAMPLE :
                    obj1 = to_obj_dict({"aaa": "111", "bbb": 222})    # obj1 = to_obj_dict(dict(aaa=111))
                    obj1.bbb = 333
                    print("obj1.aaa                 :", obj1["aaa"])  # "111"
                    print("obj1.bbb                 :", obj1.bbb)     # 222
                    print("obj1                     :", obj1)         # {'aaa': '111', 'bbb': 222}
    """
    def __init__(self, data):
        self.data = data

    def __getattr__(self, name):
        try:
            return self.data[name]
        except KeyError:
            raise AttributeError(f"'{type(self).__name__}' object has no attribute '{name}'")

    def __getitem__(self, key):
        return self.data[key]

    def __setattr__(self, name, value):
        if name == 'data':
            super().__setattr__(name, value)
        else:
            self.data[name] = value

    def __delattr__(self, name):
        try:
            del self.data[name]
        except KeyError:
            raise AttributeError(f"'{type(self).__name__}' object has no attribute '{name}'")

    def __str__(self):
        return str(self.data)

    def __repr__(self):
        return f"{type(self).__name__}({self.data})"


if __name__ == '__main__':

    obj1 = to_obj_dict({"aaa": "111", "bbb": 222})    # obj1 = to_obj_dict(dict(aaa=111))
    obj1.bbb = 333
    print("obj1.aaa                 :", obj1["aaa"])  # "111"
    print("obj1.bbb                 :", obj1.bbb)     # 222
    print("obj1                     :", obj1)         # {'aaa': '111', 'bbb': 222}

#     print(obj1)  输出   "{aaa:111}"



import win32gui


def enum_windows_callback(hwnd, param):
    text = win32gui.GetWindowText(hwnd)
    # print("text                 :", text)
    class_name = win32gui.GetClassName(hwnd)
    # print("class_name                 :" ,  class_name   )
    if text == "web - Google Chrome":
        param[0] = hwnd
        print("111                 :" ,  111   )
        return False
    return True


taskbar_handle = [None]
win32gui.EnumWindows(enum_windows_callback, taskbar_handle)

print("111                 :", taskbar_handle)
#
# if taskbar_handle[0] is not None:
#     print(f"Task bar window handle: {taskbar_handle[0]}")
# else:
#     print("Task bar window not found")



import asyncio
from pyppeteer import launch

import win32api, win32gui, win32con  # pip  install     pywin32  可能会出现问题_请看README_后端py.md

from ..fs.fs_find_file import fs_find_file
from ..win.win_find_name import win_find_name
from ..win.win_hide_taskbar import win_hide_taskbar

globals_show = ""


class SPIDER:
    def __init__(self, *args, **kwargs):
        self.show = "max"
        pass

    # 启动浏览器
    async def browser_start(self, show="max", desc="浏览器启动_位置全部隐藏", x=1, y=1):
        message = "启动浏览器了:"
        self.show = show
        executablePath = fs_find_file([r'C:\Program Files\Google\Chrome', r'C:\Users\Administrator\AppData\Local'], ["chrome.exe"])  ## chrome://version
        print("浏览器路径executablePath                 :", executablePath)
        opt_chrome = {
            "devtools": True,
            "userDataDir": r'C:\AAA_userDataDir',
            # "userDataDir": r'C:\Users\Administrator\Desktop\userdir',
            # "executablePath": r'C:\Users\Administrator\AppData\Local\Google\Chrome\Application\chrome.exe',  # 浏览器安装路径   chrome://version
            # 'executablePath': r'C:\Program Files\Google\Chrome\Application\chrome.exe',  # 浏览器安装路径   chrome://version
            # 'executablePath': r'C:\Users\Administrator\AppData\Local\360ChromeX\Chrome\Application\360ChromeX.exe',  # 浏览器安装路径   chrome://version
            "executablePath": executablePath,  # 浏览器安装路径   chrome://version
            "headless": False,  # 无头浏览器
            "dumpio": True,  # 减少内存消耗
        }

        opt_chrome["args"] = [
            "--mute-audio",  # 禁音
            '--no-sandbox',  # 关闭沙盒
            '--disable-gpu',  # 禁用 GPU 硬件加速
            # '--log-level=3',  # 日志等级
            '--disable-infobars',  # 禁用提示栏 --开启后页面加载不了
            '--start-maximized',
            '--window-size=1600,900',  # 屏幕大小
            f'--window-position={x},{y}',  # 桌面位置
            # '--blink-settings=imagesEnabled=false'  # 用图片加载
            '--disable-features=BlockingStylesheets'  # 禁用CSS加载
            '--disable-dev-shm-usage'  # 是一个用于解决Chrome/Chromium浏览器在某些特殊环境下启动问题的参数,通常会被添加到 pyppeteer 的启动参数中。
            "--user-agent=Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/78.0.3904.97 Safari/537.36",
        ]
        self.browser = await launch(opt_chrome)

        self.pages = await self.browser.pages()
        self.page = await self.browser.newPage()  # 初始化页面

        await self.page.setCacheEnabled(False)  # 禁用缓存
        self.web = self.page
        await self.web.setViewport({"width": 1920, "height": 1080})
        if self.show == "no": await self.browser_hide_taskbar()
        await self.web.evaluate('''() => { Object.defineProperty(navigator, 'webdriver', {get: () => undefined})}''')  # evaluateOnNewDocument
        zzz = 1

        message = "成功:" + desc + "      " + message
        print(message)
        return self

    # 隐藏任务栏
    async def browser_hide_taskbar(self):
        win = win_find_name("oog")
        if win:
            result = win_hide_taskbar(win["hwnd"])
            print("隐藏任务栏成功==browser_111hide_taskbar", f"result:{result}         ", win)
            return True
        else:
            raise ValueError(f"browser_hide_taskba111r 发现程序:oog        " + win)

    # 页面设置cookies_str
    async def web_set_cookies(self, desc="默认描述", cookies=""):
        message = "页面设置cookies_str了:"
        for ele in cookies:
            await self.web.setCookie(ele)
        message = "成功:" + desc + "      " + message
        print(message)
        # await asyncio.sleep(1)
        return self

    # 页面跳转
    async def web_goto(self, url="", desc="默认描述"):
        message = "页面跳转了:"
        await self.web.goto(url)
        if self.show == "no": await self.browser_hide_taskbar()
        await self.web.waitForSelector("html", timeout=10 * 1000)
        await self.web.evaluate('''() => { Object.defineProperty(navigator, 'webdriver', {get: () => undefined})}''')  # evaluateOnNewDocument
        await self.web.evaluate(""" document.title = 'web';  """)
        message = "成功:" + desc + "      " + message + url
        print(message)
        return self

    # 等待css元素
    async def web_await_css(self, css="body", desc="默认描述", timeout=10 * 1000):
        message = "等待了css元素:"
        await self.web.waitForSelector(css, timeout=timeout)
        await self.web.querySelector(css)
        message = "成功:" + desc + "      " + message + css
        print(message)
        return self

    # 点击css元素
    async def web_await_click(self, css="body", desc="默认描述", timeout=10 * 1000):
        message = "点击了css元素:"
        await self.web.waitForSelector(css, timeout=timeout)
        await self.web.click(css)
        message = "成功:" + desc + "      " + message + css
        print(message)
        return self

    # input上传文件
    async def web_await_input_files(self, css="body", desc="默认描述", files=[], timeout=10 * 1000):
        message = "input上传文件了:"
        await self.web.waitForSelector(css, timeout=timeout)
        input_element = await self.web.querySelector(css)
        await input_element.uploadFile(*files)
        message = "成功:" + desc + "      " + message + css
        print(message)
        return self

    # input输入文字
    async def web_await_input_text(self, css="body", desc="默认描述", text="hello world", timeout=10 * 1000):
        message = "input输入文字了:"
        await self.web.waitForSelector(css, timeout=timeout)
        await self.web.click(css)
        await self.web.type(css, text)
        await asyncio.sleep(0.1)
        message = "成功:" + desc + "      " + message + css
        print(message)
        return self

    # 出现css元素了关闭浏览器
    async def web_await_css_close_browser(self, desc="默认描述", css="body", timeout=10 * 1000):
        message = "出现css元素了关闭浏览器:"
        await self.web.waitForSelector(css, timeout=timeout)
        await self.browser.close()
        message = "成功:" + desc + "      " + message + css
        print(message)
        return self


# 启动浏览器窗口
async def spider_pyppeteer(show="max", desc="浏览器启动_位置全部隐藏", x=1, y=1):
    """ 启动浏览器窗口
        code
        # spider = await spider_pyppeteer()
        # spider = await __.spider.spider_pyppeteer(desc="全部显示位置",x=0, y=0)
        # spider = await __.spider.spider_pyppeteer(desc="全部隐藏位置",x=0, y=-900 + 2)
        spider = await __.spider.spider_pyppeteer(desc="一点隐藏位置", x=0, y=-900 + 100)
    """
    once = await SPIDER().browser_start(show=show, desc=desc, x=x, y=1)
    return once



import win32gui
import win32con
import ctypes
def enum_windows_callback(hwnd, param):
    text = win32gui.GetWindowText(hwnd)
    print("text                 :" ,  text   ,hwnd )



taskbar_handle = [None]
win32gui.EnumWindows(enum_windows_callback, taskbar_handle)

print("111                 :" ,  111   )















import win32api
import win32con
import win32gui
import astmain as __
import ctypes

obj1 = ""


def enum_windows_callback(hwnd, param):
    text = win32gui.GetWindowText(hwnd)
    class_name = win32gui.GetClassName(hwnd)
    left, top, right, bottom = win32gui.GetWindowRect(hwnd)
    style = win32gui.GetWindowLong(hwnd, win32con.GWL_STYLE)
    # print(f"Window handle: {hwnd}")
    # print(f"Window title: {text}")
    # print(f"Window class: {class_name}")
    # print(f"Window position: ({left}, {top}, {right}, {bottom})")
    # print(f"Window style: {hex(style)}")
    # print()

    if ("oogle" in text):
        global obj1
        obj1 = dict(text=text, class_name=class_name, hwnd=hwnd)
        # return obj1

    return True


res = win32gui.EnumWindows(enum_windows_callback, None)
obj1 = __.to_obj_dict(obj1)
print("111                 :", obj1)

win32gui.SetWindowLong(obj1.hwnd, win32con.GWL_EXSTYLE, win32gui.GetWindowLong(obj1.hwnd, win32con.GWL_EXSTYLE) | win32con.WS_EX_LAYERED)

alpha = 0
ctypes.windll.user32.SetLayeredWindowAttributes(obj1.hwnd, 0, alpha, win32con.LWA_ALPHA)

